@@ -17,7 +17,7 @@
 # under the License.
 from __future__ import annotations
 
-from collections.abc import Sequence
+from collections.abc import Callable, Sequence
 from functools import cached_property
 from typing import TYPE_CHECKING, Any
 
@@ -47,6 +47,9 @@ class GenericTransfer(BaseOperator):
     :param source_hook_params: source hook parameters.
     :param destination_conn_id: destination connection. (templated)
     :param destination_hook_params: destination hook parameters.
+    :param rows_processor: (optional) A callable applied once per batch of rows before insertion.
+        It receives the full list of rows and the task context, and must return a list of rows compatible with
+        the underlying hook's.
     :param preoperator: sql statement or list of statements to be
         executed prior to loading the data. (templated)
     :param insert_args: extra params for `insert_rows` method.
@@ -80,6 +83,9 @@ class GenericTransfer(BaseOperator):
         source_hook_params: dict | None = None,
         destination_conn_id: str,
         destination_hook_params: dict | None = None,
+        rows_processor: Callable[..., list[Any]] | None = None,
+        # rows_processor is called as rows_processor(rows, **context);
+        # context keys vary, so Callable[..., list[Any]] is intentional.
         preoperator: str | list[str] | None = None,
         insert_args: dict | None = None,
         page_size: int | None = None,
@@ -93,6 +99,7 @@ class GenericTransfer(BaseOperator):
         self.source_hook_params = source_hook_params
         self.destination_conn_id = destination_conn_id
         self.destination_hook_params = destination_hook_params
+        self._rows_processor = rows_processor
         self.preoperator = preoperator
         self.insert_args = insert_args or {}
         self.page_size = page_size
@@ -139,6 +146,14 @@ class GenericTransfer(BaseOperator):
         if isinstance(commit_every, str):
             self.insert_args["commit_every"] = int(commit_every)
 
+    def _insert_rows(self, rows: list[Any], context: Context):
+        if self._rows_processor:
+            rows = self._rows_processor(rows, **context)
+
+        self.log.info("Inserting %d rows into %s", len(rows), self.destination_conn_id)
+
+        self.destination_hook.insert_rows(table=self.destination_table, rows=rows, **self.insert_args)
+
     def execute(self, context: Context):
         if self.preoperator:
             self.log.info("Running preoperator")
@@ -162,12 +177,8 @@ class GenericTransfer(BaseOperator):
             for sql in self.sql:
                 self.log.info("Executing: \n %s", sql)
 
-                results = self.source_hook.get_records(sql)
-
-                self.log.info("Inserting rows into %s", self.destination_conn_id)
-                self.destination_hook.insert_rows(
-                    table=self.destination_table, rows=results, **self.insert_args
-                )
+                rows = self.source_hook.get_records(sql)
+                self._insert_rows(rows=rows, context=context)
 
     def execute_complete(
         self,
@@ -178,9 +189,9 @@ class GenericTransfer(BaseOperator):
             if event.get("status") == "failure":
                 raise AirflowException(event.get("message"))
 
-            results = event.get("results")
+            rows = event.get("results")
 
-            if results:
+            if rows:
                 map_index = context["ti"].map_index
                 offset = (
                     context["ti"].xcom_pull(
@@ -196,15 +207,7 @@ class GenericTransfer(BaseOperator):
                 self.log.info("Offset increased to %d", offset)
                 context["ti"].xcom_push(key="offset", value=offset)
 
-                self.log.info("Inserting %d rows into %s", len(results), self.destination_conn_id)
-                self.destination_hook.insert_rows(
-                    table=self.destination_table, rows=results, **self.insert_args
-                )
-                self.log.info(
-                    "Inserting %d rows into %s done!",
-                    len(results),
-                    self.destination_conn_id,
-                )
+                self._insert_rows(rows=rows, context=context)
 
                 self.defer(
                     trigger=SQLExecuteQueryTrigger(
